(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     92538,       1945]
NotebookOptionsPosition[     91693,       1913]
NotebookOutlinePosition[     92038,       1928]
CellTagsIndexPosition[     91995,       1925]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["American Put Options", "Section",
 CellChangeTimes->{{3.6345523302672215`*^9, 3.634552336990821*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Code by Chris Connell for the M451/M551 Financial Math Class."
}], "Text",
 CellChangeTimes->{{3.6345947434744434`*^9, 3.6345947644565415`*^9}, {
  3.6345950528463774`*^9, 3.634595071108204*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Sigma]", ",", "\[Delta]", ",", "u", ",", "n", ",", "T", ",", "K", ",", 
   "S", ",", "p", ",", "V"}], "]"}]], "Input",
 CellChangeTimes->{{3.634569600318513*^9, 3.6345696227670565`*^9}, {
  3.6345699521007676`*^9, 3.6345699524439697`*^9}}],

Cell["\<\
The Price of an American Put approximated by n steps by the function \
\[OpenCurlyDoubleQuote]PutAm\[CloseCurlyDoubleQuote] below. Here we use the \
same parameter names as in class:
 S = initial stock price, K  = Strike price, T= expiry, r= interest rate, \
\[Sigma] = volatility, and n is the number of steps used in the approximation \
(larger n better approximation but quadratically more computations needed)\
\>", "Text",
 CellChangeTimes->{{3.634591182922196*^9, 3.6345912000640497`*^9}, {
  3.63459453771987*^9, 3.634594724625559*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PutAm", "[", 
    RowBox[{
    "S_", ",", "K_", ",", "T_", ",", "r_", ",", "\[Sigma]_", ",", "n_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Delta]", "=", 
        RowBox[{"T", "/", "n"}]}], ",", "V", ",", "k", ",", "i", ",", "u", 
       ",", "d", ",", "p"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"u", "=", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"Sqrt", "[", "\[Delta]", "]"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"d", "=", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Sigma]"}], " ", 
          RowBox[{"Sqrt", "[", "\[Delta]", "]"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"r", " ", "\[Delta]"}], "-", "d"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"u", "-", "d"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"k_", ",", "i_"}], "]"}], ":=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"K", "-", 
          RowBox[{
           RowBox[{"u", "^", "i"}], " ", 
           RowBox[{"d", "^", 
            RowBox[{"(", 
             RowBox[{"k", "-", "i"}], ")"}]}], " ", "S"}]}], ",", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "r"}], " ", "\[Delta]"}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p", " ", 
             RowBox[{"V", "[", 
              RowBox[{
               RowBox[{"k", "+", "1"}], ",", 
               RowBox[{"i", "+", "1"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "p"}], ")"}], 
             RowBox[{"V", "[", 
              RowBox[{
               RowBox[{"k", "+", "1"}], ",", "i"}], "]"}]}]}], ")"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"n", ",", "i_"}], "]"}], ":=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"K", "-", 
          RowBox[{
           RowBox[{"u", "^", "i"}], " ", 
           RowBox[{"d", "^", 
            RowBox[{"(", 
             RowBox[{"n", "-", "i"}], ")"}]}], " ", "S"}]}], ",", "0"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"V", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "]"}], ";"}]}], "\[IndentingNewLine]",
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.634562656629749*^9, 3.6345627191089506`*^9}, 
   3.634562799356538*^9, {3.6345630064478655`*^9, 3.634563112076143*^9}, 
   3.6345633876050067`*^9, {3.634569464488442*^9, 3.6345695560454288`*^9}, {
   3.6345698052414265`*^9, 3.634569840341651*^9}, {3.6345699299018254`*^9, 
   3.6345699642688456`*^9}, {3.6345897652645407`*^9, 3.6345897723335404`*^9}}],

Cell["Example:", "Text",
 CellChangeTimes->{{3.6345947829783936`*^9, 3.634594785253621*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PutAm", "[", 
  RowBox[{"10", ",", "11", ",", ".1", ",", ".05", ",", ".2", ",", "10"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6345628079053926`*^9, 3.6345628591517215`*^9}, {
   3.634563120468996*^9, 3.6345631256014295`*^9}, {3.6345634011302066`*^9, 
   3.6345634054670067`*^9}, 3.6345634872042065`*^9, {3.6345899088755407`*^9, 
   3.6345899089875402`*^9}, 3.63458994245654*^9}],

Cell[BoxData["1.0001469079239693`"], "Output",
 CellChangeTimes->{{3.634562838044786*^9, 3.6345628598225255`*^9}, {
   3.634562892223933*^9, 3.634562958664759*^9}, {3.634563116834173*^9, 
   3.6345631324030733`*^9}, {3.6345633961382065`*^9, 3.634563406137807*^9}, 
   3.6345634877658067`*^9, {3.6345695608346596`*^9, 3.634569579398779*^9}, 
   3.6345696278370895`*^9, 3.6345696970859327`*^9, 3.6345698451308823`*^9, {
   3.6345699444255185`*^9, 3.6345699678412685`*^9}, 3.6345875904465404`*^9, 
   3.6345897765595407`*^9, {3.6345899380775404`*^9, 3.6345899429195404`*^9}}]
}, Open  ]],

Cell["\<\
Now we make a couple functions to plot the tree of V[i,j] values...vertically \
\>", "Text",
 CellChangeTimes->{{3.634591214412787*^9, 3.63459124118149*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphPic", "[", 
   RowBox[{"A_", ",", "L_"}], "]"}], ":=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Labeled", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "\[UndirectedEdge]", " ", 
            RowBox[{"v", "[", 
             RowBox[{
              RowBox[{"i", "+", "1"}], ",", 
              RowBox[{"j", "+", "1"}]}], "]"}]}], ",", "\"\<p\>\""}], "]"}], 
         ",", 
         RowBox[{"Labeled", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "\[UndirectedEdge]", 
            RowBox[{"v", "[", 
             RowBox[{
              RowBox[{"i", "+", "1"}], ",", "j"}], "]"}]}], ",", 
           "\"\<1-p\>\""}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{
          RowBox[{"Length", "[", "A", "]"}], "-", "2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"A", "[", 
            RowBox[{"[", 
             RowBox[{"i", "+", "1"}], "]"}], "]"}], "]"}], "-", "1"}]}], 
        "}"}]}], "]"}], " ", "]"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "\[Rule]", 
           RowBox[{"Placed", "[", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"i", "+", "1"}], ",", 
                RowBox[{"j", "+", "1"}]}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "/", "2"}], ",", 
               RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", "A", "]"}], "-", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}], "]"}], "-", "1"}]}], 
           "}"}]}], "]"}], " ", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Length", "[", "A", "]"}], "-", "1"}], ",", "j"}], 
            "]"}], "\[Rule]", 
           RowBox[{"Placed", "[", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"Length", "[", "A", "]"}], ",", 
                RowBox[{"j", "+", "1"}]}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "/", "2"}], ",", 
               RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", 
            RowBox[{
             RowBox[{"Length", "[", "A", "]"}], "-", "1"}]}], "}"}]}], 
         "]"}]}], "]"}], "]"}]}], ",", 
    RowBox[{"VertexSize", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"VertexShape", "\[Rule]", "\"\<Rectangular\>\""}], ",", "L"}], 
   "]"}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"\"\<PackingLayout\>\"", "\[Rule]", "\"\<LayeredLeft\>\""}], 
    "}"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.6345701320791216`*^9, 3.6345701454640074`*^9}, {
   3.6345702341349754`*^9, 3.6345704045595055`*^9}, {3.6345704715979905`*^9, 
   3.6345705231792536`*^9}, 3.634570654339472*^9, {3.6345707085609474`*^9, 
   3.634570758057209*^9}, {3.634570855240225*^9, 3.6345708634610033`*^9}, {
   3.6345817177136927`*^9, 3.634581719040825*^9}, {3.634581780083929*^9, 
   3.63458178059498*^9}, {3.6345849101775403`*^9, 3.6345849259835405`*^9}, {
   3.6345853429675407`*^9, 3.6345853809415407`*^9}, {3.6345855398675404`*^9, 
   3.6345855710995407`*^9}, 3.6345856486795406`*^9, {3.63458571548254*^9, 
   3.6345857176135406`*^9}, {3.6345859689555407`*^9, 3.63458603760754*^9}, {
   3.6345860743735404`*^9, 3.6345860750455403`*^9}, {3.6345861393305407`*^9, 
   3.6345861405375404`*^9}, {3.6345861739195404`*^9, 
   3.6345862149255404`*^9}, {3.6345862490365405`*^9, 
   3.6345862542505407`*^9}, {3.6345863307425404`*^9, 
   3.6345863451115403`*^9}, {3.6345864473685403`*^9, 
   3.6345864557505407`*^9}, {3.63458687211954*^9, 3.6345868765035405`*^9}, {
   3.6345869080995407`*^9, 3.6345869154835405`*^9}, {3.6345869836235404`*^9, 
   3.6345870153735404`*^9}, {3.6345870536365404`*^9, 
   3.6345870976025405`*^9}, {3.63458718795654*^9, 3.6345872415775404`*^9}, {
   3.6345873316125402`*^9, 3.6345873331645403`*^9}, {3.6345873956725407`*^9, 
   3.6345874118075404`*^9}, 3.6345874582855406`*^9, {3.6345875098655405`*^9, 
   3.6345875104735403`*^9}, {3.6345876972305403`*^9, 3.63458769757454*^9}, 
   3.6345890685825405`*^9, {3.63458914103454*^9, 3.6345892287265406`*^9}, {
   3.6345892650035405`*^9, 3.6345893133685403`*^9}, 3.6345893519665403`*^9, {
   3.6345893856935406`*^9, 3.6345894325635405`*^9}, {3.6345894924155407`*^9, 
   3.6345894930145407`*^9}, {3.6345896045845404`*^9, 
   3.6345896142945404`*^9}, {3.6345896932905407`*^9, 3.63458969344254*^9}, 
   3.63458974846354*^9, {3.6345901088275404`*^9, 3.6345901108265405`*^9}, {
   3.63459018152754*^9, 3.6345901821495404`*^9}, {3.6345902439665403`*^9, 
   3.6345902445465403`*^9}, {3.63459069159354*^9, 3.63459073177254*^9}, {
   3.6345908747348013`*^9, 3.6345908943844314`*^9}, {3.6345909398428445`*^9, 
   3.6345909835945525`*^9}, 3.634591076617482*^9, {3.6345911276925063`*^9, 
   3.6345911310618725`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PutAmGraph", "[", 
    RowBox[{
    "S_", ",", "K_", ",", "T_", ",", "r_", ",", "\[Sigma]_", ",", "n_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Delta]", "=", 
        RowBox[{"T", "/", "n"}]}], ",", "V", ",", "k", ",", "i", ",", "u", 
       ",", "d", ",", "p"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"u", "=", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"Sqrt", "[", "\[Delta]", "]"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"d", "=", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Sigma]"}], " ", 
          RowBox[{"Sqrt", "[", "\[Delta]", "]"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"r", " ", "\[Delta]"}], "-", "d"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"u", "-", "d"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"k_", ",", "i_"}], "]"}], ":=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"K", "-", 
          RowBox[{
           RowBox[{"u", "^", "i"}], " ", 
           RowBox[{"d", "^", 
            RowBox[{"(", 
             RowBox[{"k", "-", "i"}], ")"}]}], " ", "S"}]}], ",", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "r"}], " ", "\[Delta]"}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p", " ", 
             RowBox[{"V", "[", 
              RowBox[{
               RowBox[{"k", "+", "1"}], ",", 
               RowBox[{"i", "+", "1"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "p"}], ")"}], 
             RowBox[{"V", "[", 
              RowBox[{
               RowBox[{"k", "+", "1"}], ",", "i"}], "]"}]}]}], ")"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"n", ",", "i_"}], "]"}], ":=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"K", "-", 
          RowBox[{
           RowBox[{"u", "^", "i"}], " ", 
           RowBox[{"d", "^", 
            RowBox[{"(", 
             RowBox[{"n", "-", "i"}], ")"}]}], " ", "S"}]}], ",", "0"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"GraphPic", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"V", "[", 
            RowBox[{"i", ",", "j"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", "i"}], "}"}]}], "]"}], ",", 
         RowBox[{"GraphLayout", "\[Rule]", "\"\<SpringEmbedding\>\""}]}], 
        "]"}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.63458978827754*^9, 3.6345898900065403`*^9}}],

Cell["Example with n=10", "Text",
 CellChangeTimes->{{3.634594808186914*^9, 3.6345948118262777`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PutAmGraph", "[", 
  RowBox[{"10", ",", "11", ",", ".1", ",", ".05", ",", ".2", ",", "10"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.63458992259354*^9, 3.6345899329855404`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
       $CellContext`v[0, 0], 
       $CellContext`v[1, 1], 
       $CellContext`v[1, 0], 
       $CellContext`v[2, 1], 
       $CellContext`v[2, 0], 
       $CellContext`v[2, 2], 
       $CellContext`v[3, 1], 
       $CellContext`v[3, 0], 
       $CellContext`v[3, 2], 
       $CellContext`v[3, 3], 
       $CellContext`v[4, 1], 
       $CellContext`v[4, 0], 
       $CellContext`v[4, 2], 
       $CellContext`v[4, 3], 
       $CellContext`v[4, 4], 
       $CellContext`v[5, 1], 
       $CellContext`v[5, 0], 
       $CellContext`v[5, 2], 
       $CellContext`v[5, 3], 
       $CellContext`v[5, 4], 
       $CellContext`v[5, 5], 
       $CellContext`v[6, 1], 
       $CellContext`v[6, 0], 
       $CellContext`v[6, 2], 
       $CellContext`v[6, 3], 
       $CellContext`v[6, 4], 
       $CellContext`v[6, 5], 
       $CellContext`v[6, 6], 
       $CellContext`v[7, 1], 
       $CellContext`v[7, 0], 
       $CellContext`v[7, 2], 
       $CellContext`v[7, 3], 
       $CellContext`v[7, 4], 
       $CellContext`v[7, 5], 
       $CellContext`v[7, 6], 
       $CellContext`v[7, 7], 
       $CellContext`v[8, 1], 
       $CellContext`v[8, 0], 
       $CellContext`v[8, 2], 
       $CellContext`v[8, 3], 
       $CellContext`v[8, 4], 
       $CellContext`v[8, 5], 
       $CellContext`v[8, 6], 
       $CellContext`v[8, 7], 
       $CellContext`v[8, 8], 
       $CellContext`v[9, 1], 
       $CellContext`v[9, 0], 
       $CellContext`v[9, 2], 
       $CellContext`v[9, 3], 
       $CellContext`v[9, 4], 
       $CellContext`v[9, 5], 
       $CellContext`v[9, 6], 
       $CellContext`v[9, 7], 
       $CellContext`v[9, 8], 
       $CellContext`v[9, 9], 
       $CellContext`v[10, 1], 
       $CellContext`v[10, 0], 
       $CellContext`v[10, 2], 
       $CellContext`v[10, 3], 
       $CellContext`v[10, 4], 
       $CellContext`v[10, 5], 
       $CellContext`v[10, 6], 
       $CellContext`v[10, 7], 
       $CellContext`v[10, 8], 
       $CellContext`v[10, 9], 
       $CellContext`v[10, 10]}, {
      Null, {{1, 2}, {1, 3}, {3, 4}, {3, 5}, {2, 6}, {2, 4}, {5, 7}, {5, 8}, {
       4, 9}, {4, 7}, {6, 10}, {6, 9}, {8, 11}, {8, 12}, {7, 13}, {7, 11}, {9,
        14}, {9, 13}, {10, 15}, {10, 14}, {12, 16}, {12, 17}, {11, 18}, {11, 
       16}, {13, 19}, {13, 18}, {14, 20}, {14, 19}, {15, 21}, {15, 20}, {17, 
       22}, {17, 23}, {16, 24}, {16, 22}, {18, 25}, {18, 24}, {19, 26}, {19, 
       25}, {20, 27}, {20, 26}, {21, 28}, {21, 27}, {23, 29}, {23, 30}, {22, 
       31}, {22, 29}, {24, 32}, {24, 31}, {25, 33}, {25, 32}, {26, 34}, {26, 
       33}, {27, 35}, {27, 34}, {28, 36}, {28, 35}, {30, 37}, {30, 38}, {29, 
       39}, {29, 37}, {31, 40}, {31, 39}, {32, 41}, {32, 40}, {33, 42}, {33, 
       41}, {34, 43}, {34, 42}, {35, 44}, {35, 43}, {36, 45}, {36, 44}, {38, 
       46}, {38, 47}, {37, 48}, {37, 46}, {39, 49}, {39, 48}, {40, 50}, {40, 
       49}, {41, 51}, {41, 50}, {42, 52}, {42, 51}, {43, 53}, {43, 52}, {44, 
       54}, {44, 53}, {45, 55}, {45, 54}, {47, 56}, {47, 57}, {46, 58}, {46, 
       56}, {48, 59}, {48, 58}, {49, 60}, {49, 59}, {50, 61}, {50, 60}, {51, 
       62}, {51, 61}, {52, 63}, {52, 62}, {53, 64}, {53, 63}, {54, 65}, {54, 
       64}, {55, 66}, {55, 65}}}, {EdgeLabels -> {UndirectedEdge[
           $CellContext`v[9, 8], 
           $CellContext`v[10, 9]] -> "p", UndirectedEdge[
           $CellContext`v[6, 1], 
           $CellContext`v[7, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 4], 
           $CellContext`v[9, 4]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 2], 
           $CellContext`v[7, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[2, 2], 
           $CellContext`v[3, 3]] -> "p", UndirectedEdge[
           $CellContext`v[6, 5], 
           $CellContext`v[7, 6]] -> "p", UndirectedEdge[
           $CellContext`v[5, 4], 
           $CellContext`v[6, 4]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 6], 
           $CellContext`v[7, 6]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 3], 
           $CellContext`v[10, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[0, 0], 
           $CellContext`v[1, 1]] -> "p", UndirectedEdge[
           $CellContext`v[1, 0], 
           $CellContext`v[2, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[2, 0], 
           $CellContext`v[3, 1]] -> "p", UndirectedEdge[
           $CellContext`v[8, 2], 
           $CellContext`v[9, 3]] -> "p", UndirectedEdge[
           $CellContext`v[3, 1], 
           $CellContext`v[4, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 4], 
           $CellContext`v[10, 5]] -> "p", UndirectedEdge[
           $CellContext`v[6, 4], 
           $CellContext`v[7, 5]] -> "p", UndirectedEdge[
           $CellContext`v[7, 3], 
           $CellContext`v[8, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[7, 4], 
           $CellContext`v[8, 4]] -> "1-p", UndirectedEdge[
           $CellContext`v[4, 2], 
           $CellContext`v[5, 3]] -> "p", UndirectedEdge[
           $CellContext`v[6, 1], 
           $CellContext`v[7, 2]] -> "p", UndirectedEdge[
           $CellContext`v[4, 1], 
           $CellContext`v[5, 2]] -> "p", UndirectedEdge[
           $CellContext`v[7, 5], 
           $CellContext`v[8, 6]] -> "p", UndirectedEdge[
           $CellContext`v[4, 0], 
           $CellContext`v[5, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[3, 3], 
           $CellContext`v[4, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[4, 1], 
           $CellContext`v[5, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 3], 
           $CellContext`v[9, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[7, 2], 
           $CellContext`v[8, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 4], 
           $CellContext`v[9, 5]] -> "p", UndirectedEdge[
           $CellContext`v[5, 1], 
           $CellContext`v[6, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 5], 
           $CellContext`v[9, 6]] -> "p", UndirectedEdge[
           $CellContext`v[9, 7], 
           $CellContext`v[10, 7]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 2], 
           $CellContext`v[9, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 0], 
           $CellContext`v[10, 1]] -> "p", UndirectedEdge[
           $CellContext`v[1, 1], 
           $CellContext`v[2, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[2, 1], 
           $CellContext`v[3, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[1, 1], 
           $CellContext`v[2, 2]] -> "p", UndirectedEdge[
           $CellContext`v[9, 5], 
           $CellContext`v[10, 5]] -> "1-p", UndirectedEdge[
           $CellContext`v[7, 6], 
           $CellContext`v[8, 6]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 3], 
           $CellContext`v[7, 4]] -> "p", UndirectedEdge[
           $CellContext`v[4, 4], 
           $CellContext`v[5, 5]] -> "p", UndirectedEdge[
           $CellContext`v[8, 0], 
           $CellContext`v[9, 1]] -> "p", UndirectedEdge[
           $CellContext`v[6, 6], 
           $CellContext`v[7, 7]] -> "p", UndirectedEdge[
           $CellContext`v[7, 5], 
           $CellContext`v[8, 5]] -> "1-p", UndirectedEdge[
           $CellContext`v[4, 4], 
           $CellContext`v[5, 4]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 2], 
           $CellContext`v[6, 3]] -> "p", UndirectedEdge[
           $CellContext`v[4, 3], 
           $CellContext`v[5, 4]] -> "p", UndirectedEdge[
           $CellContext`v[9, 6], 
           $CellContext`v[10, 6]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 5], 
           $CellContext`v[7, 5]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 9], 
           $CellContext`v[10, 9]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 3], 
           $CellContext`v[6, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 0], 
           $CellContext`v[6, 1]] -> "p", UndirectedEdge[
           $CellContext`v[2, 0], 
           $CellContext`v[3, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 5], 
           $CellContext`v[6, 6]] -> "p", UndirectedEdge[
           $CellContext`v[7, 2], 
           $CellContext`v[8, 3]] -> "p", UndirectedEdge[
           $CellContext`v[8, 7], 
           $CellContext`v[9, 8]] -> "p", UndirectedEdge[
           $CellContext`v[9, 3], 
           $CellContext`v[10, 4]] -> "p", UndirectedEdge[
           $CellContext`v[5, 3], 
           $CellContext`v[6, 4]] -> "p", UndirectedEdge[
           $CellContext`v[0, 0], 
           $CellContext`v[1, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 5], 
           $CellContext`v[6, 5]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 8], 
           $CellContext`v[9, 8]] -> "1-p", UndirectedEdge[
           $CellContext`v[3, 2], 
           $CellContext`v[4, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 1], 
           $CellContext`v[10, 2]] -> "p", UndirectedEdge[
           $CellContext`v[8, 5], 
           $CellContext`v[9, 5]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 1], 
           $CellContext`v[6, 2]] -> "p", UndirectedEdge[
           $CellContext`v[7, 0], 
           $CellContext`v[8, 1]] -> "p", UndirectedEdge[
           $CellContext`v[8, 6], 
           $CellContext`v[9, 7]] -> "p", UndirectedEdge[
           $CellContext`v[8, 1], 
           $CellContext`v[9, 2]] -> "p", UndirectedEdge[
           $CellContext`v[8, 3], 
           $CellContext`v[9, 4]] -> "p", UndirectedEdge[
           $CellContext`v[4, 2], 
           $CellContext`v[5, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[4, 3], 
           $CellContext`v[5, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 7], 
           $CellContext`v[9, 7]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 9], 
           $CellContext`v[10, 10]] -> "p", UndirectedEdge[
           $CellContext`v[9, 4], 
           $CellContext`v[10, 4]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 0], 
           $CellContext`v[7, 1]] -> "p", UndirectedEdge[
           $CellContext`v[7, 7], 
           $CellContext`v[8, 8]] -> "p", UndirectedEdge[
           $CellContext`v[7, 1], 
           $CellContext`v[8, 2]] -> "p", UndirectedEdge[
           $CellContext`v[9, 2], 
           $CellContext`v[10, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 6], 
           $CellContext`v[9, 6]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 6], 
           $CellContext`v[10, 7]] -> "p", UndirectedEdge[
           $CellContext`v[6, 2], 
           $CellContext`v[7, 3]] -> "p", UndirectedEdge[
           $CellContext`v[3, 0], 
           $CellContext`v[4, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 3], 
           $CellContext`v[7, 3]] -> "1-p", UndirectedEdge[
           $CellContext`v[7, 0], 
           $CellContext`v[8, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[3, 0], 
           $CellContext`v[4, 1]] -> "p", UndirectedEdge[
           $CellContext`v[1, 0], 
           $CellContext`v[2, 1]] -> "p", UndirectedEdge[
           $CellContext`v[8, 8], 
           $CellContext`v[9, 9]] -> "p", UndirectedEdge[
           $CellContext`v[9, 7], 
           $CellContext`v[10, 8]] -> "p", UndirectedEdge[
           $CellContext`v[3, 1], 
           $CellContext`v[4, 2]] -> "p", UndirectedEdge[
           $CellContext`v[9, 2], 
           $CellContext`v[10, 3]] -> "p", UndirectedEdge[
           $CellContext`v[5, 0], 
           $CellContext`v[6, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[6, 0], 
           $CellContext`v[7, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 1], 
           $CellContext`v[10, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[7, 6], 
           $CellContext`v[8, 7]] -> "p", UndirectedEdge[
           $CellContext`v[7, 4], 
           $CellContext`v[8, 5]] -> "p", UndirectedEdge[
           $CellContext`v[3, 3], 
           $CellContext`v[4, 4]] -> "p", UndirectedEdge[
           $CellContext`v[8, 0], 
           $CellContext`v[9, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[7, 3], 
           $CellContext`v[8, 4]] -> "p", UndirectedEdge[
           $CellContext`v[5, 2], 
           $CellContext`v[6, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[2, 1], 
           $CellContext`v[3, 2]] -> "p", UndirectedEdge[
           $CellContext`v[6, 4], 
           $CellContext`v[7, 4]] -> "1-p", UndirectedEdge[
           $CellContext`v[8, 1], 
           $CellContext`v[9, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[3, 2], 
           $CellContext`v[4, 3]] -> "p", UndirectedEdge[
           $CellContext`v[7, 7], 
           $CellContext`v[8, 7]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 0], 
           $CellContext`v[10, 0]] -> "1-p", UndirectedEdge[
           $CellContext`v[5, 4], 
           $CellContext`v[6, 5]] -> "p", UndirectedEdge[
           $CellContext`v[9, 5], 
           $CellContext`v[10, 6]] -> "p", UndirectedEdge[
           $CellContext`v[2, 2], 
           $CellContext`v[3, 2]] -> "1-p", UndirectedEdge[
           $CellContext`v[4, 0], 
           $CellContext`v[5, 1]] -> "p", UndirectedEdge[
           $CellContext`v[7, 1], 
           $CellContext`v[8, 1]] -> "1-p", UndirectedEdge[
           $CellContext`v[9, 8], 
           $CellContext`v[10, 8]] -> "1-p"}, GraphLayout -> "SpringEmbedding",
        VertexLabels -> {$CellContext`v[9, 0] -> Placed[2.6472978858872835`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 8] -> Placed[0, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 9] -> Placed[0., {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 3] -> 
         Placed[1.582354664157517, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 4] -> 
         Placed[0.5996781092560305, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 5] -> 
         Placed[0.40782140456577176`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 0] -> 
         Placed[2.8126924692201865`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 2] -> 
         Placed[1.7688365361336462`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[5, 1] -> 
         Placed[1.582354664157517, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[4, 1] -> 
         Placed[1.3921056084767702`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 7] -> 
         Placed[0.16712932325041585`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 3] -> 
         Placed[1.0000000000000018`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 5] -> 
         Placed[0.5918922580761219, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 7] -> 
         Placed[0.019935249751698168`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 0] -> 
         Placed[2.1307956328284288`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[3, 1] -> 
         Placed[1.198013266932449, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 10] -> Placed[0, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[2, 1] -> 
         Placed[1.0000000000000018`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 8] -> Placed[0., {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[3, 0] -> 
         Placed[1.5823546641575152`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[5, 2] -> 
         Placed[1.198013266932449, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 1] -> 
         Placed[2.3064176460119477`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[5, 4] -> 
         Placed[0.4313895834694073, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 3] -> 
         Placed[1.198013266932449, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 5] -> 
         Placed[0.7979865997324467, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[3, 2] -> 
         Placed[0.8025026371991002, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[1, 0] -> 
         Placed[1.1980132669324473`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 0] -> 
         Placed[2.47856211033789, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[3, 3] -> 
         Placed[0.4527020309754359, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 4] -> 
         Placed[1.1980132669324508`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[2, 0] -> 
         Placed[1.3921056084767685`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 1] -> 
         Placed[2.1307956328284305`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[4, 3] -> 
         Placed[0.611632965415579, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[4, 2] -> 
         Placed[1.0000000000000018`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 6] -> 
         Placed[0.1335602902000169, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 6] -> 
         Placed[0.5918922580761201, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 7] -> 
         Placed[0.08227015775063443, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[0, 0] -> 
         Placed[1.0001469079239693`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[5, 5] -> 
         Placed[0.17064872119548383`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 3] -> 
         Placed[1.7688365361336462`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 1] -> 
         Placed[2.478562110337892, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[4, 0] -> 
         Placed[1.7688365361336444`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[4, 4] -> 
         Placed[0.29891427517613084`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 5] -> 
         Placed[1.0000000000000036`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 7] -> 
         Placed[0.04049785354645977, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[2, 2] -> 
         Placed[0.6246666513077231, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 2] -> 
         Placed[1.9516258196404088`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 1] -> 
         Placed[1.9516258196404088`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[1, 1] -> 
         Placed[0.8091139176338942, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 3] -> 
         Placed[1.3921056084767702`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 2] -> 
         Placed[2.1307956328284305`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 4] -> 
         Placed[0.7979865997324449, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 2] -> 
         Placed[1.3921056084767702`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 1] -> 
         Placed[1.7688365361336462`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 2] -> 
         Placed[1.582354664157517, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 4] -> 
         Placed[1.0000000000000036`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[9, 6] -> 
         Placed[0.3816345345464054, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 5] -> 
         Placed[0.2684997883947918, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 8] -> Placed[0., {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[5, 3] -> 
         Placed[0.7979865997324431, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 9] -> Placed[0, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[8, 6] -> 
         Placed[0.22959248794134174`, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[7, 0] -> 
         Placed[2.306417646011946, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[6, 6] -> 
         Placed[0.07585771957527788, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[5, 0] -> 
         Placed[1.951625819640407, {
            Rational[1, 2], 
            Rational[1, 2]}], $CellContext`v[10, 4] -> 
         Placed[1.392105608476772, {
            Rational[1, 2], 
            Rational[1, 2]}]}, VertexShape -> {"Rectangular"}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], {
         {Arrowheads[0.], 
          ArrowBox[{{7.524228287505091, 6.936277376159218}, {
           6.813517266062636, 6.26444620483738}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.168872776783863, 6.600361790498299}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.524228287505091, 6.936277376159218}, {8.24012770085311,
            6.267814475692454}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.8821779941791, 6.602045925925836}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.813517266062636, 6.26444620483738}, {7.529023146879062,
            5.546387591867536}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.171270206470849, 5.905416898352458}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.813517266062636, 6.26444620483738}, {6.103888557826503,
            5.599186955914687}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {6.458702911944569, 5.931816580376034}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.24012770085311, 6.267814475692454}, {7.529023146879062,
            5.546387591867536}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.884575423866086, 5.907101033779995}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.24012770085311, 6.267814475692454}, {8.953981254733783,
            5.605693297792616}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {8.597054477793446, 5.936753886742535}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.529023146879062, 5.546387591867536}, {
           8.242603082806019, 4.844585307388182}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.8858131148425405`, 5.195486449627859}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.529023146879062, 5.546387591867536}, {
           6.819218401050946, 4.841310325304625}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.174120773965004, 5.193848958586081}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.953981254733783, 5.605693297792616}, {
           8.242603082806019, 4.844585307388182}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {8.598292168769902, 5.225139302590399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.953981254733783, 5.605693297792616}, {
           9.642600516603832, 4.9586173671466565`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {9.298290885668807, 5.282155332469636}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.103888557826503, 5.599186955914687}, {
           6.819218401050946, 4.841310325304625}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {6.461553479438724, 5.220248640609656}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.103888557826503, 5.599186955914687}, {
           5.419243934444168, 4.948997390486237}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {5.761566246135335, 5.274092173200462}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.242603082806019, 4.844585307388182}, {8.93873905200504,
            4.166104904713452}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {8.59067106740553, 4.505345106050817}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.242603082806019, 4.844585307388182}, {
           7.532586681793678, 4.100356771258333}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.887594882299848, 4.472471039323258}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.642600516603832, 4.9586173671466565`}, {
           8.93873905200504, 4.166104904713452}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {9.290669784304436, 4.562361135930054}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.642600516603832, 4.9586173671466565`}, {
           10.320237402410836`, 4.341240775370011}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {9.981418959507334, 4.649929071258334}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.819218401050946, 4.841310325304625}, {
           7.532586681793678, 4.100356771258333}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.175902541422312, 4.47083354828148}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.819218401050946, 4.841310325304625}, {
           6.126697452656599, 4.159490154471995}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {6.4729579268537725`, 4.50040023988831}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.419243934444168, 4.948997390486237}, {
           6.126697452656599, 4.159490154471995}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {5.772970693550384, 4.554243772479117}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.419243934444168, 4.948997390486237}, {
           4.745633155016593, 4.328653676866171}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {5.082438544730381, 4.638825533676204}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.93873905200504, 4.166104904713452}, {9.636401934798695,
            3.5229208846026583`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {9.287570493401867, 3.844512894658055}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.93873905200504, 4.166104904713452}, {8.236435475140782,
            3.394814469806353}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {8.58758726357291, 3.780459687259903}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{10.320237402410836`, 4.341240775370011}, {
           9.636401934798695, 3.5229208846026583`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {9.978319668604765, 3.932080829986335}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{10.320237402410836`, 4.341240775370011}, {
           11.007168285310867`, 3.7641510582140554`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {10.66370284386085, 4.052695916792033}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.532586681793678, 4.100356771258333}, {
           8.236435475140782, 3.394814469806353}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.88451107846723, 3.7475856205323432`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.532586681793678, 4.100356771258333}, {6.83216844817049,
            3.3914295546423787`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.182377564982084, 3.745893162950356}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.126697452656599, 4.159490154471995}, {6.83216844817049,
            3.3914295546423787`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {6.479432950413544, 3.775459854557187}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.126697452656599, 4.159490154471995}, {
           5.432476926629144, 3.5128438741781105`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {5.779587189642871, 3.836167014325053}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.745633155016593, 4.328653676866171}, {
           5.432476926629144, 3.5128438741781105`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {5.089055040822869, 3.920748775522141}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.745633155016593, 4.328653676866171}, {
           4.063776094244093, 3.7492099746279943`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {4.404704624630343, 4.038931825747083}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.636401934798695, 3.5229208846026583`}, {
           10.362922821428818`, 2.8982044676476266`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {9.999662378113756, 3.2105626761251425`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.636401934798695, 3.5229208846026583`}, {
           8.949020905898001, 2.719275450852143}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {9.292711420348347, 3.121098167727401}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.007168285310867`, 3.7641510582140554`}, {
           10.362922821428818`, 2.8982044676476266`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {10.685045553369843`, 3.331177762930841}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.007168285310867`, 3.7641510582140554`}, {
           11.748650883156179`, 3.1990931749018046`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {11.377909584233523`, 3.48162211655793}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.236435475140782, 3.394814469806353}, {
           8.949020905898001, 2.719275450852143}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {8.592728190519392, 3.057044960329248}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.236435475140782, 3.394814469806353}, {
           7.535878693326129, 2.6573659045260563`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.886157084233456, 3.0260901871662047`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.83216844817049, 3.3914295546423787`}, {
           7.535878693326129, 2.6573659045260563`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.18402357074831, 3.0243977295842175`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.83216844817049, 3.3914295546423787`}, {
           6.122721679452157, 2.7121454106257183`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {6.477445063811324, 3.0517874826340483`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.432476926629144, 3.5128438741781105`}, {
           6.122721679452157, 2.7121454106257183`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {5.777599303040651, 3.1124946424019146`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.432476926629144, 3.5128438741781105`}, {
           4.7092081868796765`, 2.8846041333868957`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {5.07084255675441, 3.198724003782503}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.063776094244093, 3.7492099746279943`}, {
           4.7092081868796765`, 2.8846041333868957`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {4.386492140561884, 3.3169070540074452`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.063776094244093, 3.7492099746279943`}, {
           3.3258451889954994`, 3.1815573899803855`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {3.6948106416197963`, 3.46538368230419}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{10.362922821428818`, 2.8982044676476266`}, {
           11.13190360466391, 2.3050359829787412`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {10.747413213046364`, 2.6016202253131837`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{10.362922821428818`, 2.8982044676476266`}, {
           9.692208807141554, 2.0777938941005667`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {10.027565814285186`, 2.4879991808740964`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.748650883156179`, 3.1990931749018046`}, {
           11.13190360466391, 2.3050359829787412`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {11.440277243910044`, 2.752064578940273}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.748650883156179`, 3.1990931749018046`}, {
           12.526927114470176`, 2.700682404567145}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {12.137788998813178`, 2.9498877897344746`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.949020905898001, 2.719275450852143}, {
           9.692208807141554, 2.0777938941005667`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {9.320614856519779, 2.3985346724763548`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.949020905898001, 2.719275450852143}, {
           8.253189250187049, 1.9730904587816687`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {8.601105078042526, 2.3461829548169058`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.535878693326129, 2.6573659045260563`}, {
           8.253189250187049, 1.9730904587816687`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.894533971756589, 2.3152281816538625`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.535878693326129, 2.6573659045260563`}, {
           6.821517987883284, 1.969366384617416}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.178698340604706, 2.313366144571736}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.122721679452157, 2.7121454106257183`}, {
           6.821517987883284, 1.969366384617416}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {6.472119833667721, 2.340755897621567}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.122721679452157, 2.7121454106257183`}, {
           5.382331779879358, 2.0669627707834373`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {5.752526729665758, 2.3895540907045776`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.7092081868796765`, 2.8846041333868957`}, {
           5.382331779879358, 2.0669627707834373`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {5.045769983379517, 2.4757834520851665`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.7092081868796765`, 2.8846041333868957`}, {
           3.9429074859028836`, 2.287958272445721}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {4.32605783639128, 2.5862812029163083`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.3258451889954994`, 3.1815573899803855`}, {
           3.9429074859028836`, 2.287958272445721}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {3.6343763374491918`, 2.734757831213053}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.3258451889954994`, 3.1815573899803855`}, {
           2.549876698530161, 2.681875268973097}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {2.9378609437628302`, 2.931716329476741}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.13190360466391, 2.3050359829787412`}, {
           11.951948940101461`, 1.7799855892955072`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {11.541926272382685`, 2.0425107861371243`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.13190360466391, 2.3050359829787412`}, {
           10.484990099347167`, 1.4678015222589864`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {10.808446852005538`, 1.8864187526188638`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{12.526927114470176`, 2.700682404567145}, {
           11.951948940101461`, 1.7799855892955072`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {12.239438027285818`, 2.240333996931326}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{12.526927114470176`, 2.700682404567145}, {
           13.353526296046313`, 2.3075453343212877`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {12.940226705258244`, 2.5041138694442164`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.692208807141554, 2.0777938941005667`}, {
           10.484990099347167`, 1.4678015222589864`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {10.08859945324436, 1.7727977081797766`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.692208807141554, 2.0777938941005667`}, {
           9.004950210648127, 1.3247145213422622`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {9.34857950889484, 1.7012542077214143`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.253189250187049, 1.9730904587816687`}, {
           9.004950210648127, 1.3247145213422622`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {8.629069730417587, 1.6489024900619653`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.253189250187049, 1.9730904587816687`}, {
           7.538887929625022, 1.2827363282157198`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.896038589906036, 1.6279133934986942`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.821517987883284, 1.969366384617416}, {
           7.538887929625022, 1.2827363282157198`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.180202958754153, 1.626051356416568}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.821517987883284, 1.969366384617416}, {
           6.072541213065462, 1.317204962826539}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {6.447029600474373, 1.6432856737219774`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.382331779879358, 2.0669627707834373`}, {
           6.072541213065462, 1.317204962826539}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {5.727436496472411, 1.692083866804988}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.382331779879358, 2.0669627707834373`}, {
           4.591339291573421, 1.4534865107893717`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {4.98683553572639, 1.7602246407864044`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.9429074859028836`, 2.287958272445721}, {
           4.591339291573421, 1.4534865107893717`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {4.267123388738153, 1.8707223916175462`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.9429074859028836`, 2.287958272445721}, {
           3.1231745136325006`, 1.760972530141499}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {3.5330409997676924`, 2.02446540129361}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{2.549876698530161, 2.681875268973097}, {
           3.1231745136325006`, 1.760972530141499}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {2.836525606081331, 2.2214238995572977`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{2.549876698530161, 2.681875268973097}, {
           1.7235861355991648`, 2.2908912005083897`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {2.136731417064663, 2.4863832347407433`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.951948940101461`, 1.7799855892955072`}, {
           12.823854271240954`, 1.350392000494628}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {12.387901605671207`, 1.5651887948950676`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.951948940101461`, 1.7799855892955072`}, {
           11.32434762293683, 0.9212366627258395}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {11.638148281519147`, 1.3506111260106732`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{13.353526296046313`, 2.3075453343212877`}, {
           12.823854271240954`, 1.350392000494628}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {13.088690283643633`, 1.828968667407958}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{13.353526296046313`, 2.3075453343212877`}, {
           14.221216566871727`, 2.0459211289743555`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {13.78737143145902, 2.1767332316478214`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{10.484990099347167`, 1.4678015222589864`}, {
           11.32434762293683, 0.9212366627258395}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {10.904668861142, 1.194519092492413}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{10.484990099347167`, 1.4678015222589864`}, {
           9.806511269766922, 0.703925169928086}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {10.145750684557044`, 1.0858633460935363`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.004950210648127, 1.3247145213422622`}, {
           9.806511269766922, 0.703925169928086}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {9.405730740207524, 1.014319845635174}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.004950210648127, 1.3247145213422622`}, {
           8.292990038406082, 0.6315305557753257}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {8.648970124527104, 0.9781225385587939}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.538887929625022, 1.2827363282157198`}, {
           8.292990038406082, 0.6315305557753257}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.915938984015552, 0.9571334419955227}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{7.538887929625022, 1.2827363282157198`}, {
           6.7875684556802875`, 0.6276878003862072}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.163228192652655, 0.9552120643009635}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.072541213065462, 1.317204962826539}, {
           6.7875684556802875`, 0.6276878003862072}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {6.430054834372875, 0.9724463816063731}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.072541213065462, 1.317204962826539}, {
           5.272719672683033, 0.6929219010043484}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {5.672630442874247, 1.0050634319154437`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.591339291573421, 1.4534865107893717`}, {
           5.272719672683033, 0.6929219010043484}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {4.932029482128227, 1.07320420589686}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{4.591339291573421, 1.4534865107893717`}, {
           3.751830371628889, 0.9048488957736396}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {4.171584831601155, 1.1791677032815056`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.1231745136325006`, 1.760972530141499}, {
           3.751830371628889, 0.9048488957736396}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {3.437502442630695, 1.3329107129575692`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.1231745136325006`, 1.760972530141499}, {
           2.2488327516736746`, 1.3331640398147284`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {2.6860036326530876`, 1.5470682849781137`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{1.7235861355991648`, 2.2908912005083897`}, {
           2.2488327516736746`, 1.3331640398147284`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {1.9862094436364197`, 1.812027620161559}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{1.7235861355991648`, 2.2908912005083897`}, {
           0.8523573109506559, 2.040082382453999}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {1.2879717232749104`, 2.1654867914811944`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{12.823854271240954`, 1.350392000494628}, {
           13.741920394350492`, 1.098045517823675}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {13.282887332795724`, 1.2242187591591516`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{12.823854271240954`, 1.350392000494628}, {
           12.213815701430356`, 0.497402391852511}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {12.518834986335655`, 0.9238971961735695}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{14.221216566871727`, 2.0459211289743555`}, {
           13.741920394350492`, 1.098045517823675}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {13.98156848061111, 1.5719833233990153`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{14.221216566871727`, 2.0459211289743555`}, {
           15.087322567813494`, 2.138011020443873}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {14.65426956734261, 2.091966074709114}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.32434762293683, 0.9212366627258395}, {
           12.213815701430356`, 0.497402391852511}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {11.769081662183593`, 0.7093195272891752}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{11.32434762293683, 0.9212366627258395}, {
           10.648184624296668`, 0.1703344305640826}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {10.98626612361675, 0.545785546644961}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.806511269766922, 0.703925169928086}, {
           10.648184624296668`, 0.1703344305640826}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {10.227347947031795`, 0.4371298002460843}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{9.806511269766922, 0.703925169928086}, {
           9.094112042216747, 0.029632251460607772`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {9.450311655991834, 0.36677871069434687`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.292990038406082, 0.6315305557753257}, {
           9.094112042216747, 0.029632251460607772`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {8.693551040311414, 0.33058140361796673`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{8.292990038406082, 0.6315305557753257}, {
           7.541780115057591, 0.}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {7.917385076731836, 0.31576527788766284`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.7875684556802875`, 0.6276878003862072}, {
           7.541780115057591, 0.}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {7.164674285368939, 0.3138439001931036}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{6.7875684556802875`, 0.6276878003862072}, {
           5.988592085539723, 0.02231554513217837}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {6.388080270610006, 0.3250016727591928}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.272719672683033, 0.6929219010043484}, {
           5.988592085539723, 0.02231554513217837}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {5.630655879111378, 0.35761872306826337`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{5.272719672683033, 0.6929219010043484}, {
           4.431565487398895, 0.1572353358814036}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {4.852142580040964, 0.425078618442876}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.751830371628889, 0.9048488957736396}, {
           4.431565487398895, 0.1572353358814036}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {4.091697929513892, 0.5310421158275216}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{3.751830371628889, 0.9048488957736396}, {
           2.860156940479527, 0.48290134967964615`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {3.3059936560542083`, 0.6938751227266429}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{2.2488327516736746`, 1.3331640398147284`}, {
           2.860156940479527, 0.48290134967964615`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {2.554494846076601, 0.9080326947471873}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{2.2488327516736746`, 1.3331640398147284`}, {
           1.3248738867998906`, 1.0945640176295226`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {1.7868533192367826`, 1.2138640287221256`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{0.8523573109506559, 2.040082382453999}, {
           1.3248738867998906`, 1.0945640176295226`}}, 0.08052497343965713]}, 
         InsetBox["\<\"1-p\"\>", {1.0886155988752733`, 1.567323200041761}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Arrowheads[0.], 
          ArrowBox[{{0.8523573109506559, 2.040082382453999}, {0., 
           2.2264132563015675`}}, 0.08052497343965713]}, 
         InsetBox["\<\"p\"\>", {0.42617865547532796`, 2.1332478193777833`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], {
         TagBox[
          InsetBox["Rectangular", {7.524228287505091, 6.936277376159218}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.0001469079239693`", {7.524228287505091, 6.936277376159218},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.813517266062636, 6.26444620483738}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.8091139176338942`", {6.813517266062636, 6.26444620483738},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.24012770085311, 6.267814475692454}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.1980132669324473`", {8.24012770085311, 6.267814475692454},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {7.529023146879062, 5.546387591867536}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.0000000000000018`", {7.529023146879062, 5.546387591867536},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.953981254733783, 5.605693297792616}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.3921056084767685`", {8.953981254733783, 5.605693297792616},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.103888557826503, 5.599186955914687}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.6246666513077231`", {6.103888557826503, 5.599186955914687},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.242603082806019, 4.844585307388182}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.198013266932449`", {8.242603082806019, 4.844585307388182},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {9.642600516603832, 4.9586173671466565`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.5823546641575152`", {9.642600516603832, 4.9586173671466565`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.819218401050946, 4.841310325304625}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.8025026371991002`", {6.819218401050946, 4.841310325304625},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {5.419243934444168, 4.948997390486237}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.4527020309754359`", {5.419243934444168, 4.948997390486237},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.93873905200504, 4.166104904713452}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.3921056084767702`", {8.93873905200504, 4.166104904713452},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {10.320237402410836`, 4.341240775370011}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], 
         InsetBox["1.7688365361336444`", {10.320237402410836`, 4.341240775370011},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {7.532586681793678, 4.100356771258333}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.0000000000000018`", {7.532586681793678, 4.100356771258333},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.126697452656599, 4.159490154471995}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.611632965415579`", {6.126697452656599, 4.159490154471995},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {4.745633155016593, 4.328653676866171}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.29891427517613084`", {4.745633155016593, 4.328653676866171},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {9.636401934798695, 3.5229208846026583`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.582354664157517`", {9.636401934798695, 3.5229208846026583`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {11.007168285310867`, 3.7641510582140554`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.951625819640407`", {11.007168285310867`, 3.7641510582140554`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.236435475140782, 3.394814469806353}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.198013266932449`", {8.236435475140782, 3.394814469806353},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.83216844817049, 3.3914295546423787`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.7979865997324431`", {6.83216844817049, 3.3914295546423787`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {5.432476926629144, 3.5128438741781105`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.4313895834694073`", {5.432476926629144, 3.5128438741781105`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {4.063776094244093, 3.7492099746279943`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.17064872119548383`", {4.063776094244093, 3.7492099746279943`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {10.362922821428818`, 2.8982044676476266`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.7688365361336462`", {10.362922821428818`, 2.8982044676476266`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {11.748650883156179`, 3.1990931749018046`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.1307956328284288`", {11.748650883156179`, 3.1990931749018046`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.949020905898001, 2.719275450852143}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.3921056084767702`", {8.949020905898001, 2.719275450852143},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {7.535878693326129, 2.6573659045260563`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.0000000000000018`", {7.535878693326129, 2.6573659045260563`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.122721679452157, 2.7121454106257183`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.5996781092560305`", {6.122721679452157, 2.7121454106257183`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {4.7092081868796765`, 2.8846041333868957`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.2684997883947918`", {4.7092081868796765`, 2.8846041333868957`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {3.3258451889954994`, 3.1815573899803855`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.07585771957527788`", {3.3258451889954994`, 3.1815573899803855`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {11.13190360466391, 2.3050359829787412`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.9516258196404088`", {11.13190360466391, 2.3050359829787412`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {12.526927114470176`, 2.700682404567145}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.306417646011946`", {12.526927114470176`, 2.700682404567145},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {9.692208807141554, 2.0777938941005667`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.582354664157517`", {9.692208807141554, 2.0777938941005667`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.253189250187049, 1.9730904587816687`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.198013266932449`", {8.253189250187049, 1.9730904587816687`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.821517987883284, 1.969366384617416}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.7979865997324449`", {6.821517987883284, 1.969366384617416},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {5.382331779879358, 2.0669627707834373`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.40782140456577176`", {5.382331779879358, 2.0669627707834373`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {3.9429074859028836`, 2.287958272445721}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.1335602902000169`", {3.9429074859028836`, 2.287958272445721},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {2.549876698530161, 2.681875268973097}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.019935249751698168`", {2.549876698530161, 2.681875268973097},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {11.951948940101461`, 1.7799855892955072`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.1307956328284305`", {11.951948940101461`, 1.7799855892955072`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {13.353526296046313`, 2.3075453343212877`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.47856211033789`", {13.353526296046313`, 2.3075453343212877`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {10.484990099347167`, 1.4678015222589864`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.7688365361336462`", {10.484990099347167`, 1.4678015222589864`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {9.004950210648127, 1.3247145213422622`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.3921056084767702`", {9.004950210648127, 1.3247145213422622`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {7.538887929625022, 1.2827363282157198`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.0000000000000036`", {7.538887929625022, 1.2827363282157198`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.072541213065462, 1.317204962826539}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.5918922580761219`", {6.072541213065462, 1.317204962826539},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {4.591339291573421, 1.4534865107893717`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.22959248794134174`", {4.591339291573421, 1.4534865107893717`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {3.1231745136325006`, 1.760972530141499}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.04049785354645977`", {3.1231745136325006`, 1.760972530141499},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {1.7235861355991648`, 2.2908912005083897`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.`", {1.7235861355991648`, 2.2908912005083897`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {12.823854271240954`, 1.350392000494628}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.3064176460119477`", {12.823854271240954`, 1.350392000494628},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {14.221216566871727`, 2.0459211289743555`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.6472978858872835`", {14.221216566871727`, 2.0459211289743555`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {11.32434762293683, 0.9212366627258395}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.9516258196404088`", {11.32434762293683, 0.9212366627258395},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {9.806511269766922, 0.703925169928086}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.582354664157517`", {9.806511269766922, 0.703925169928086},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {8.292990038406082, 0.6315305557753257}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.1980132669324508`", {8.292990038406082, 0.6315305557753257},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {6.7875684556802875`, 0.6276878003862072}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.7979865997324467`", {6.7875684556802875`, 0.6276878003862072},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {5.272719672683033, 0.6929219010043484}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.3816345345464054`", {5.272719672683033, 0.6929219010043484},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {3.751830371628889, 0.9048488957736396}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.08227015775063443`", {3.751830371628889, 0.9048488957736396},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {2.2488327516736746`, 1.3331640398147284`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.`", {2.2488327516736746`, 1.3331640398147284`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {0.8523573109506559, 2.040082382453999}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.`", {0.8523573109506559, 2.040082382453999},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {13.741920394350492`, 1.098045517823675}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.478562110337892`", {13.741920394350492`, 1.098045517823675},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {15.087322567813494`, 2.138011020443873}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.8126924692201865`", {15.087322567813494`, 2.138011020443873},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {12.213815701430356`, 0.497402391852511}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["2.1307956328284305`", {12.213815701430356`, 0.497402391852511},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {10.648184624296668`, 0.1703344305640826}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.7688365361336462`", {10.648184624296668`, 0.17033443056408262`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {9.094112042216747, 0.029632251460607772`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.392105608476772`", {9.094112042216747, 0.029632251460607772`},
          BaseStyle->"Graphics"]}, {
         TagBox[InsetBox["Rectangular", {7.541780115057591, 0.}, Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["1.0000000000000036`", {7.541780115057591, 0.},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {5.988592085539723, 0.02231554513217837}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.5918922580761201`", {5.988592085539723, 0.02231554513217837},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {4.431565487398895, 0.1572353358814036}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0.16712932325041585`", {4.431565487398895, 0.15723533588140362`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {2.860156940479527, 0.48290134967964615`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0", {2.860156940479527, 0.48290134967964615`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {1.3248738867998906`, 1.0945640176295226`}, 
           Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0", {1.3248738867998906`, 1.0945640176295226`},
          BaseStyle->"Graphics"]}, {
         TagBox[
          InsetBox["Rectangular", {0., 2.2264132563015675`}, Automatic, {0.16104994687931426`, 0.16104994687931426`}],
          "InsetString"], InsetBox["0", {0., 2.2264132563015675`},
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->{886., Automatic}]], "Output",
 CellChangeTimes->{3.6345899484365406`*^9, 3.6345910914853354`*^9, 
  3.634591146335567*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{994, 912},
WindowMargins->{{Automatic, 69}, {Automatic, 34}},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 107, 1, 70, "Section"],
Cell[690, 25, 263, 6, 30, "Text"],
Cell[956, 33, 293, 6, 31, "Input"],
Cell[1252, 41, 553, 9, 68, "Text"],
Cell[1808, 52, 3067, 85, 172, "Input"],
Cell[4878, 139, 92, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[4995, 144, 406, 7, 31, "Input"],
Cell[5404, 153, 572, 7, 31, "Output"]
}, Open  ]],
Cell[5991, 163, 167, 3, 30, "Text"],
Cell[6161, 168, 5931, 136, 172, "Input"],
Cell[12095, 306, 3144, 90, 172, "Input"],
Cell[15242, 398, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[15368, 403, 203, 4, 31, "Input"],
Cell[15574, 409, 76091, 1500, 456, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
